#
# spec file for package libcomps
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2021 Neal Gompa <ngompa13@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define major 0
%define minor 1
%define patch 20
%define libname %{name}%{major}
%define devname %{name}-devel

Name:           libcomps
Version:        %{major}.%{minor}.%{patch}
Release:        3.1
Summary:        Comps XML file manipulation library
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/rpm-software-management/libcomps
Source0:        %{url}/archive/%{version}/%{name}-%{version}.tar.gz
Patch0:         libcomps-c99.patch

BuildRequires:  %{python_module setuptools}
BuildRequires:  check-devel
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libexpat-devel
BuildRequires:  libxml2-devel
BuildRequires:  python-rpm-macros
BuildRequires:  zlib-devel

# prevent provides from nonstandard paths:
%define __provides_exclude ^(%{python3_sitearch}/.*\\.so)$

%description
Libcomps is library for structure-like manipulation with content of
comps XML files. Supports read/write XML file, structure(s) modification.

%package -n %{libname}
Summary:        Libraries for %{name}
Group:          System/Libraries

%description -n %{libname}
Libraries for %{name}

%package -n %{devname}
Summary:        Development files for the libcomps library
Group:          Development/Libraries/C and C++
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Requires:       pkgconfig

%description -n %{devname}
This package provides the development files for %{name}.

%package doc
Summary:        Documentation files for libcomps library
Group:          Documentation/HTML
BuildArch:      noarch
BuildRequires:  doxygen

%description doc
Documentation files for libcomps library.

%package -n python-libcomps-doc
Summary:        Documentation files for python bindings libcomps library
Group:          Documentation/HTML
BuildArch:      noarch
BuildRequires:  python3-Sphinx

%description -n python-libcomps-doc
Documentation files for python bindings libcomps library.

%package -n python3-libcomps
Summary:        Python 3 bindings for libcomps library
Group:          Development/Libraries/Python
BuildRequires:  python3-devel
Requires:       %{libname}%{?_isa} = %{version}-%{release}
# There is no more Python 2 subpackage
Obsoletes:      python2-libcomps < 0.1.9

%description -n python3-libcomps
This package provides the Python 3 bindings for libcomps library.

%prep
%autosetup  -p1

%build
%cmake -DPYTHON_DESIRED:STRING=3 ../libcomps/
%make_build
make docs
make pydocs

%check
pushd ./build
make test
popd

%install
pushd ./build
%make_install
popd

mkdir -p %{buildroot}%{_datadir}/doc/libcomps/
cp -a build/docs/libcomps-doc/html %{buildroot}%{_datadir}/doc/libcomps/

mkdir -p %{buildroot}%{_datadir}/doc/python-libcomps/
rm build/src/python/docs/html/.doctrees/environment.pickle
cp -a build/src/python/docs/html %{buildroot}%{_datadir}/doc/python-libcomps/

%python_compileall
%fdupes %{buildroot}%{python3_sitearch}

%fdupes %{buildroot}%{_datadir}/doc/libcomps
%fdupes %{buildroot}%{_datadir}/doc/python-libcomps

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%{_libdir}/libcomps.so.%{major}
%doc README.md
%license COPYING

%files -n %{devname}
%{_libdir}/libcomps.so
%{_libdir}/pkgconfig/libcomps.pc
%{_includedir}/*

%files doc
%doc %{_datadir}/doc/libcomps

%files -n python-libcomps-doc
%doc %{_datadir}/doc/python-libcomps

%files -n python3-libcomps
%{python3_sitearch}/libcomps/
%{python3_sitearch}/libcomps-%{version}*-info

%changelog
* Wed Jul 10 2024 Martin Jambor <mjambor@suse.com>
- Add libcomps-c99.patch in order to avoid C99 violations which are
  errors by default with GCC 14.  [boo#1221700]
* Mon Dec  4 2023 Ana Guerrero <ana.guerrero@suse.com>
- Add BuildRequires on python-setuptools to create python egg and
  install it properly. Previously this was pulled by python-Sphinx
  in the build environment.
- Use %%license instead of %%doc
* Sat Nov  4 2023 Neal Gompa <ngompa@opensuse.org>
- Update to 0.1.20
  + Fixes of xml parsing
  + Fix non-optimized builds by removing inline keyword
  + Use Py_hash_t instead of long
* Fri Feb 24 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- Precompile python bytecode (boo#1208151)
* Sat Sep 24 2022 Dirk Müller <dmueller@suse.com>
- update to 0.1.19:
  * handle upload to pypi
* Wed Nov  3 2021 Neal Gompa <ngompa13@gmail.com>
- Upgrade to 0.1.18
  + Fix several covscan warnings
* Fri Aug 27 2021 Neal Gompa <ngompa13@gmail.com>
- Upgrade to 0.1.17
  + Fix a crash when clearing COMPS_ObjRTree (rh#1888343)
  + Don't print empty requires
  + Fix memory leaks and resource leaks
  + Remove Python 2 support
- Drop patch included in this release
  + Patch: fix-sphinx.patch
* Wed Jun  9 2021 Martin Liška <mliska@suse.cz>
- Add upstream patch fix-sphinx.patch which fixes build with Sphinx 4.x.
* Tue Apr 13 2021 Neal Gompa <ngompa13@gmail.com>
- Upgrade to 0.1.16
  + Fix a crash when clearing COMPS_ObjRTree (rh#1888343)
  + Fixes for leaks and crashes
* Sat Jun  6 2020 Neal Gompa <ngompa13@gmail.com>
- Upgrade to 0.1.15
  + Do not skip type=mandatory in xml output and test it (rh#1771224)
  + Remove unused global variable UnfoObjListIt (rh#1793424)
  + Make inline function __comps_objmrtree_all also static (rh#1793424)
* Tue Dec  3 2019 Neal Gompa <ngompa13@gmail.com>
- Upgrade to 0.1.14
  + Fix reference to versioned libcomps.so
* Tue Dec  3 2019 Neal Gompa <ngompa13@gmail.com>
- Upgrade to 0.1.13
  + Fix massively broken libcomps pkgconfig file
  + Change libcomps soversion to use only the version major
* Sun Dec  1 2019 Neal Gompa <ngompa13@gmail.com>
- Upgrade to 0.1.12
  + Fix order of asserts() in unit test (rh#1713220)
  + Fix Python method descriptors for Python 3.8 (rh#1734777)
  + Refactor pkgconfig file generation and install properly
  + Fix segfault when converting empty dict to string (rh#1757959)
  + Add missing python metadata to python3-libcomps
  + Refactor building and installing Python bindings
* Sun Mar 31 2019 Neal Gompa <ngompa13@gmail.com>
- Upgrade to 0.1.11
  + Fix missing braces
  + Fix UAF in comps_objmrtree_unite function
- Drop merged patches
  * 0001-Fix-Missing-braces.patch
  * 0002-Fix-UAF-in-comps_objmrtree_unite-function.patch
  * libcomps-0.1.7-Add-zlib-as-an-explicit-dependency.patch
* Thu Feb  7 2019 Jan Engelhardt <jengelh@inai.de>
- Update RPM groups
* Sun Feb  3 2019 Neal Gompa <ngompa13@gmail.com>
- Upgrade to 0.1.9
  + Fix memory leaks
  + Remove unused code
- Backport fix for logic error
  * Patch: 0001-Fix-Missing-braces.patch
- Backport fix for CVE-2019-3817 (boo#1122841)
  * Patch: 0002-Fix-UAF-in-comps_objmrtree_unite-function.patch
- Drop Python 2 subpackage
- Adjust changes entries to use full author identities
* Sun Sep 17 2017 Bernhard Wiedemann <bwiedemann@suse.com>
- Drop environment.pickle from doc to make build reproducible
* Sun Aug 13 2017 Neal Gompa <ngompa13@gmail.com>
- Upgrade to 0.1.8
* Mon Feb  1 2016 Neal Gompa <ngompa13@gmail.com>
- Initial packaging of libcomps based on Mageia packaging
